@@ -1,12 +1,11 @@
-# pylint: disable=too-many-instance-attributes
 #!/usr/bin/env python
 
 import re, regex
 import sys
 import enum
 from pathlib import Path
-sys.path.append(Path(__file__).parent.as_posix()) # https://stackoverflow.com/questions/16981921
-from constants import DATAFILE, USERFILE, URLREGX
+sys.path.append(Path(__file__).parent.parent.as_posix()) # https://stackoverflow.com/questions/16981921
+from negar.constants import DATAFILE, USERFILE, URLREGX
 
 class State(enum.Enum):
     save = 1
